Index: /trunk/src/VBox/Main/idl/VirtualBox.xidl
===================================================================
--- /trunk/src/VBox/Main/idl/VirtualBox.xidl	(revision 83649)
+++ /trunk/src/VBox/Main/idl/VirtualBox.xidl	(revision 83650)
@@ -26680,13 +26680,37 @@
 
   <interface name="ICloudMachine" extends="$unknown"
-             uuid="c26e1432-7a04-11ea-901f-3bf60e81ed96"
+             uuid="bcb7c6d6-7a6e-11ea-9839-7f4258c13c14"
              wsmap="managed"
              reservedMethods="16" reservedAttributes="8">
     <desc>
       Virtual virtual machine (sic) in the cloud.
+
+      Reading object attributes returns cached values, use
+      <link to="#refresh"/> to refresh them.
     </desc>
 
     <attribute name="id" type="uuid" mod="string" readonly="yes">
       <desc>UUID of the cloud machine.</desc>
+    </attribute>
+
+    <attribute name="accessible" type="boolean" readonly="yes"
+               wrap-hint-server="limitedcaller">
+      <desc>
+        Whether this virtual machine is currently accessible or not.
+        TBD...
+      </desc>
+    </attribute>
+
+    <attribute name="accessError" type="IVirtualBoxErrorInfo" readonly="yes"
+               wrap-hint-server="limitedcaller">
+      <desc>
+        Error information describing the reason of machine
+        inaccessibility.
+
+        Reading this property is only valid after the last call to
+        <link to="#accessible"/> returned @c false (i.e. the
+        machine is currently inaccessible). Otherwise, a @c null
+        IVirtualBoxErrorInfo object will be returned.
+      </desc>
     </attribute>
 
@@ -26707,4 +26731,21 @@
     </attribute>
 
+    <attribute name="state" type="MachineState" readonly="yes">
+      <desc>
+        Machine state.
+      </desc>
+    </attribute>
+
+    <method name="refresh">
+      <desc>
+        Refresh information by reading it from the cloud.
+      </desc>
+      <param name="progress" type="IProgress" dir="return">
+        <desc>
+          Progress object to track the operation completion.
+        </desc>
+      </param>
+    </method>
+
     <method name="getSettingsForm">
       <desc>
@@ -26723,21 +26764,4 @@
       </param>
     </method>
-
-    <method name="readState">
-      <desc>
-        Read the state of the cloud machine and make it available via
-        the <link to="#state"/> attribute.
-      </desc>
-      <param name="progress" type="IProgress" dir="return">
-        <desc>
-          Progress object to track the operation completion.
-        </desc>
-      </param>
-    </method>
-    <attribute name="state" type="MachineState" readonly="yes">
-      <desc>
-        See <link to="#readState"/>.
-      </desc>
-    </attribute>
 
     <method name="powerUp">

Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 83649)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 83650)
@@ -220,6 +220,6 @@
                                                      QWidget *pParent /* = 0 */)
 {
-    /* Execute ReadState async method: */
-    CProgress comProgress = comCloudMachine.ReadState();
+    /* Execute Refresh async method: */
+    CProgress comProgress = comCloudMachine.Refresh();
     if (!comCloudMachine.isOk())
     {